#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("./config");
const data_source_1 = require("./data_source");
const index_1 = require("./generated/index");
const types_1 = require("./generated/types");
const service_common_1 = require("@crosslab/service-common");
async function startUpdateService() {
    await data_source_1.AppDataSource.initialize();
    index_1.app.get('/update/status', (_req, res) => {
        res.send({ status: 'ok' });
    });
    index_1.app.initService({
        security: {
            JWT: (0, service_common_1.JWTVerify)(config_1.config, types_1.isUserTypeJWT, service_common_1.parseJwtFromAuthorizationHeader),
        },
        preHandlers: [service_common_1.requestIdHandling, service_common_1.logHandling],
        postHandlers: [service_common_1.missingRouteHandling],
        errorHandler: service_common_1.errorHandler,
    });
    index_1.app.listen(config_1.config.PORT);
    service_common_1.logger.log('info', 'Update Service started successfully');
}
/* istanbul ignore if */
if (require.main === module) {
    startUpdateService();
}
//# sourceMappingURL=index.js.map